*Extract the country from the variable "country" (remove the last 4 characters from the string)

cap drop country2

gen country2=substr(country, 1, strlen(country) - 4)

order country country2 

*Generate the variable iso3 code

kountry country2, stuck from(other)
rename _ISO3N_ temp
kountry temp, from(iso3n) to(iso3c)
drop temp
rename _ISO3C_ iso3

* Missing information filled out with World Bank Country and Lending Groups: https://datahelpdesk.worldbank.org/knowledgebase/articles/906519-world-bank-country-and-lending-groups

replace iso3="COD" if country2=="DRC"
replace iso3="SWZ" if country2=="Eswatini"
replace iso3="SLV" if country2=="ElSalvador"
replace iso3="ATG" if country2=="Antiguaandbarbuda"
replace iso3="BFA" if country2=="BurkinaFaso"
replace iso3="CPV" if country2=="CapeVerde"
replace iso3="CZE" if country2=="Czechia"
replace iso3="CIV" if country2=="Côte d'Ivoire"
replace iso3="DOM" if country2=="DominicanRepublic"
replace iso3="HKG" if country2=="Hong Kong SAR China"
replace iso3="XKX" if country2=="Kosovo"
replace iso3="LAO" if country2=="LaoPDR"
replace iso3="MKD" if country2=="North Macedonia"
replace iso3="PNG" if country2=="PapuaNewGuinea"
replace iso3="ZAF" if country2=="SouthAfrica"
replace iso3="SSD" if country2=="Southsudan"
replace iso3="LKA" if country2=="SriLanka"
replace iso3="KNA" if country2=="StKittsandNevis"
replace iso3="LCA" if country2=="StLucia"
replace iso3="VCT" if country2=="StVincentandGrenadines"
replace iso3="TTO" if country2=="TrinidadandTobago"
replace iso3="TUR" if country2=="Türkiye"

***

*Extract the year from the variable "country" (extract the last 4 characters from the string)

cap drop fin_country
generate fin_country=substr(country,-4,4)

order fin_country country


*Convert the string variable "fin_country" to a numeric variable (float)

cap drop destr_fin_country
destring fin_country , generate(destr_fin_country) float

order fin_country country destr_fin_country

*Generate the variable "year"

cap drop year
gen year=a20y // 129,741 missing values generated
replace year=a14y-1 if year==. // 99,976 real changes made

*Use the last 4 characters from the variable "country" if a20y is either missing or -9 to generate the variable "year"

replace year=destr_fin_country if year==. | a20y==-9 | a14y==-8 | a14y==2301 // 29,772 real changes made 

/* Download data on GDP per capita from the World Bank WDI - Data downloaded on Nov 19 2024 - this part of the code commented out 
preserve
wbopendata, indicator(ny.gdp.pcap.pp.kd) clear long
rename countrycode iso3
keep iso3 year ny_gdp_pcap_pp_kd
label var ny_gdp_pcap_pp_kd "GDP per capita, PPP (constant 2021 international $)"
save "${WORKING_DIR}/Data/GDP_percapita.dta", replace
restore
*/

merge m:1 iso3 year using "${WORKING_DIR}/Data/GDP_percapita.dta"
drop if _merge==2
drop _merge

* Missing information on GDP per capita filled out with data from previous or following year 
replace ny_gdp_pcap_pp_kd=14033.62 if ny_gdp_pcap_pp_kd==. & iso3=="BTN" & year==2023 // 155	real	changes	made
replace ny_gdp_pcap_pp_kd=4506.222 if ny_gdp_pcap_pp_kd==. & iso3=="DJI" & year==2012 // replaced with 2013 value. 266 real changes made
replace ny_gdp_pcap_pp_kd=7088.515 if ny_gdp_pcap_pp_kd==. & iso3=="XKX" & year==2007 // replaced with 2008 value. 246 real changes made

* Values for Eritrea and South Sudan not available;  multiple values for Venezuela and Yemen not available

* Download data on culture from here: https://geerthofstede.com/research-and-vsm/dimension-data-matrix/ - this part of the code commented out 
*We are using the 2015 12 08 0-100 version, so data will be assigned from 2015 onwards
preserve
import excel "${WORKING_DIR}/Data/6-dimensions-for-website-2015-12-08-0-100.xls", sheet("6 dimensions for website") firstrow clear

kountry country, stuck from(other)
rename _ISO3N_ temp
kountry temp, from(iso3n) to(iso3c)
drop temp
rename _ISO3C_ iso3

replace iso3="MKD" if country=="Macedonia Rep"
replace iso3="SVK" if country=="Slovak Rep"

* Apply values for Africa East and Africa West to countries not in the data base
expand 20 if country=="Africa East", gen(input_culture)

replace iso3="AGO" in 112
replace iso3="BWA" in 113
replace iso3="BDI" in 114
replace iso3="COM" in 115
replace iso3="COD" in 116
replace iso3="ERI" in 117
replace iso3="SWZ" in 118
replace iso3="KEN" in 119
replace iso3="LSO" in 120
replace iso3="MDG" in 121
replace iso3="MWI" in 122
replace iso3="MUS" in 123
replace iso3="MOZ" in 124
replace iso3="NAM" in 125
replace iso3="STP" in 126
replace iso3="SYC" in 127
replace iso3="SOM" in 128
replace iso3="SSD" in 129
replace iso3="SDN" in 130

expand 17 if country=="Africa West" , gen(input_culture1)

replace iso3="CPV" in 131
replace iso3="CMR" in 132
replace iso3="TCD" in 133
replace iso3="COG" in 134
replace iso3="CIV" in 135
replace iso3="GNQ" in 136
replace iso3="GAB" in 137
replace iso3="GMB" in 138
replace iso3="GIN" in 139
replace iso3="GNB" in 140
replace iso3="LBR" in 141
replace iso3="MRT" in 142
replace iso3="NER" in 143
replace iso3="SEN" in 144
replace iso3="SLE" in 145
replace iso3="TGO" in 146

replace input_culture=1 if input_culture1==1

drop if iso3==""

keep pdi-input_culture iso3
save "${WORKING_DIR}/Data/culture.dta", replace
restore


merge m:1 iso3 using "${WORKING_DIR}/Data/culture.dta"
* Value of culture variables set to missing for years before 2015

replace pdi=. if year<2015
replace idv=. if year<2015
replace mas=. if year<2015
replace uai=. if year<2015
replace ltowvs=. if year<2015
replace ivr=. if year<2015
    
* Countries not merged are the ones for which there is no ES data as of 2024, e.g. USA and CAN
drop if _merge==2
drop _merge

*** COMPUTE RELEVANT VARIABLES FOR THE ANALYSES

* Technological orientation
*https://www.oecd.org/content/dam/oecd/en/publications/reports/2016/07/oecd-taxonomy-of-economic-activities-based-on-r-d-intensity_g17a283b/5jlv73sqqp8r-en.pdf


cap drop man_non
gen man_non=.

*High R&D intensity

*manufacturing
replace man_non=1 if isic_v4==21 | isic_v4==26

*non-manufacturing
replace man_non=1 if isic_v4==72

*Medium-high R&D intensity

*manufacturing
replace man_non=1 if isic_v4==30 | isic_v4==29 | isic_v4==28 | isic_v4==20 | isic_v4==27

*non-manufacturing
replace man_non=1 if isic_v4==58 | isic_v4==62 | isic_v4==63

*Medium R&D intensity

*manufacturing
replace man_non=1 if isic_v4==22 | isic_v4==32 | isic_v4==23 | isic_v4==24 | isic_v4==33

*Medium-low R&D intensity

*manufacturing
replace man_non=0 if isic_v4==13
replace man_non=0 if isic_v4==25
replace man_non=0 if isic_v4==15
replace man_non=0 if isic_v4==17
replace man_non=0 if isic_v4==10
replace man_non=0 if isic_v4==11
replace man_non=0 if isic_v4==12
replace man_non=0 if isic_v4==14
replace man_non=0 if isic_v4==19
replace man_non=0 if isic_v4==31
replace man_non=0 if isic_v4==16
replace man_non=0 if isic_v4==18

*non-manufacturing
replace man_non=0 if isic_v4==69
replace man_non=0 if isic_v4==70
replace man_non=0 if isic_v4==71
replace man_non=0 if isic_v4==73
replace man_non=0 if isic_v4==74
replace man_non=0 if isic_v4==75
replace man_non=0 if isic_v4==61
replace man_non=0 if isic_v4==05
replace man_non=0 if isic_v4==06
replace man_non=0 if isic_v4==07
replace man_non=0 if isic_v4==08
replace man_non=0 if isic_v4==09

*Low R&D intensity
*non-manufacturing
replace man_non=0 if isic_v4==64
replace man_non=0 if isic_v4==65
replace man_non=0 if isic_v4==66
replace man_non=0 if isic_v4==35
replace man_non=0 if isic_v4==36
replace man_non=0 if isic_v4==37
replace man_non=0 if isic_v4==38
replace man_non=0 if isic_v4==39
replace man_non=0 if isic_v4==59
replace man_non=0 if isic_v4==60
replace man_non=0 if isic_v4==45
replace man_non=0 if isic_v4==46
replace man_non=0 if isic_v4==47
replace man_non=0 if isic_v4==01
replace man_non=0 if isic_v4==02
replace man_non=0 if isic_v4==03
replace man_non=0 if isic_v4==41
replace man_non=0 if isic_v4==42
replace man_non=0 if isic_v4==43
replace man_non=0 if isic_v4==77
replace man_non=0 if isic_v4==78
replace man_non=0 if isic_v4==79
replace man_non=0 if isic_v4==80
replace man_non=0 if isic_v4==81
replace man_non=0 if isic_v4==82
replace man_non=0 if isic_v4==90
replace man_non=0 if isic_v4==91
replace man_non=0 if isic_v4==92
replace man_non=0 if isic_v4==93
replace man_non=0 if isic_v4==94
replace man_non=0 if isic_v4==95
replace man_non=0 if isic_v4==96
replace man_non=0 if isic_v4==97
replace man_non=0 if isic_v4==98
replace man_non=0 if isic_v4==99
replace man_non=0 if isic_v4==49
replace man_non=0 if isic_v4==50
replace man_non=0 if isic_v4==51
replace man_non=0 if isic_v4==52
replace man_non=0 if isic_v4==53
replace man_non=0 if isic_v4==55
replace man_non=0 if isic_v4==56
replace man_non=0 if isic_v4==68

label var man_non "Tech orientation"

***
** Dichothomus  variables: --> yes=1, no=0

*"Is the top manager female?"

cap drop top_man_fem
gen top_man_fem=1 if b7a==1
*yes

replace top_man_fem=0 if b7a==2
*no

label var top_man_fem "Company employs female top managers"



* *"establishment has its own website or a social media page" 
cap drop web_soc
gen web_soc=1 if c22b==1
replace web_soc=0 if c22b==2
label var web_soc "Digital orientation"


*"Over the last 3 years, establishment monitor its CO2 emissions?
cap drop mon_emi
gen mon_emi=1 if ge7==1
replace mon_emi=0 if ge7==2

order ge7 mon_emi year

label var mon_emi "Firm has monitored its CO2 emissions over the past 3 years"

*"Formal training programs for permanent, full time employees in last fiscal year"

cap drop training
gen training=1 if l10==1
*yes

replace training=0 if l10==2
*no

label var training "Formal training programs for permanent, full time employees in last fiscal year"


*Establishment Has A Line Of Credit Or Loan From A Financial Institution?
cap drop fin_ins
gen fin_ins=1 if k8==1
*yes

replace fin_ins=0 if k8==2
*no

label var fin_ins "Establishment Has A Line Of Credit Or Loan From A Financial Institution"

* Large dummy Based On Strata
cap drop large
gen large=(size==3) 

label var large "Large(100 And Over workers)"


* Dicothomus variable for time spent In Dealing With Govt Regulations
cap drop tim_spe
gen tim_spe=0 if j2>=0 & j2<50
replace tim_spe=1 if j2>=50 & j2!=.

label var tim_spe "Senior management's time spent on dealing with regulations"



***
** Interactions

cap drop enc_country2
encode country2 , generate(enc_country2)

*interaction year*country

cap drop int_yea_cou
gen int_yea_cou = year*enc_country2



*interaction industry*country

cap drop int_ind_cou
gen int_ind_cou = isic_v4*enc_country2



***
** Other variables
* Log of GDP per capita
cap drop ln_GDPpercapita
gen ln_GDPpercapita=ln(ny_gdp_pcap_pp_kd)

lab var ln_GDPpercapita "Log GDP per capita, PPP (constant 2021 international $)"

* Variable age
cap drop establishment
gen Year_establishment=b5
replace Year_establishment=. if b5==-9 | b5==-8 | b5==-3 | b5==1 | b5==60 | b5==2205 // non response or outliers

cap drop age
gen age=year-Year_establishment

replace age=0 if age==-1 // correction to take into account some discrepancy in the year of establishment arising from the use of a14y-1 , 96 obs changed
replace age=. if age==-3 // correction to take into account some discrepancy in the year of establishment arising from the use of a14y-1, 1 obs changed


lab var age "Age of the establishment at the time of the interview"

order year Year_establishment b5 age

* Set sales growth equal to performance indicator 1
gen sal_gro=perf1
label var sal_gro "Real annual sales growth (%)"

* Generate variable for courts as a major or very sever obstacle
cap drop courts
gen courts=1 if   h30==3 | h30==4
replace courts=0 if h30==0 | h30==1 | h30==2

label var courts "Courts perceived as a major or very severe obstacle"
